@@ -19,6 +19,9 @@ pub enum TokenWhitelistError {
     /// Token Whitelist Size Exceeds
     #[error("Token Whitelist Size Exceeds")]
     TokenWhitelistSizeExceeds,
+    /// Signer Not Account Owner
+    #[error("Signer Not Account Owner")]
+    NotOwner,
 }
 
 impl From<TokenWhitelistError> for ProgramError {
