@@ -160,8 +160,8 @@ impl Processor {
     ) -> ProgramResult {
         let account_info_iter = &mut accounts.iter();
 
-        let whitelist_owner = next_account_info(account_info_iter)?;
-        if !whitelist_owner.is_signer {
+        let account_owner = next_account_info(account_info_iter)?;
+        if !account_owner.is_signer {
             return Err(ProgramError::MissingRequiredSignature);
         }
 
@@ -173,11 +173,11 @@ impl Processor {
             msg!("token whitelist needs to be initialized before attempting to update");
             return Err(TokenWhitelistError::TokenWhitelistNotInit.into());
         }
-        if whitelist_owner.key != &token_whitelist_state.init_pubkey {
-            msg!("signer must be whitelist owner");
-            msg!("{}", whitelist_owner.key);
-            msg!("{}", token_whitelist_state.init_pubkey);
-            return Err(TokenWhitelistError::TokenWhitelistNotOwner.into());
+        if account_owner.key != account_to_reset.key {
+            msg!("signer must be the owner of the account");
+            msg!("{}", account_owner.key);
+            msg!("{}", account_to_reset.key);
+            return Err(TokenWhitelistError::NotOwner.into());
         }
 
         let whitelist_amount: u64 = 0;
@@ -199,6 +199,7 @@ impl PrintProgramError for TokenWhitelistError {
             TokenWhitelistError::TokenWhitelistNotInit => msg!("Error: Token Whitelist Not Initialized"),
             TokenWhitelistError::TokenWhitelistNotOwner => msg!("Error: Signer Not Token Whitelist Owner"),
             TokenWhitelistError::TokenWhitelistSizeExceeds => msg!("Error: Token Whitelist Size Exceeds"),
+            TokenWhitelistError::NotOwner => msg!("Error: Signer Not Account Owner"),
         }
     }
 }
